==> showyourwork-0.3.0.dev10.tar.gz: showyourwork-0.3.0.dev10/README.md <==
<p align="center">
    <a href="https://github.com/showyourwork/showyourwork">
        <img width = "450" src="https://raw.githubusercontent.com/showyourwork/.github/main/images/showyourwork.png" alt="showyourwork"/>
    </a>
    <br/>
    <a href="https://github.com/showyourwork/showyourwork/actions/workflows/tests.yml">
        <img src="https://github.com/showyourwork/showyourwork/actions/workflows/tests.yml/badge.svg" alt="tests"/>
    </a>
    <a href="https://showyourwork.readthedocs.io">
        <img src="https://img.shields.io/static/v1?label=read&message=the%20docs&color=blue" alt="tests"/>
    </a>
    <a href="https://pypi.org/project/showyourwork/">
        <img src="https://img.shields.io/pypi/v/showyourwork" alt="pypi"/>
    </a>
</p>

Welcome to `showyourwork!`, a workflow management tool for open source scientific articles. If you want to make your research article **reproducible**, **extensible**, **transparent**, or **just downright awesome**, you’ve found the right tool. `showyourwork!` automates your entire workflow, packaging it into a self-contained recipe that anyone can follow and—at the click of a button—use to reproduce your results.

Please check out the [documentation](https://showyourwork.readthedocs.io) for more information about this project. The [quickstart tutorial](https://showyourwork.readthedocs.io/en/latest/quickstart) should get you up and running fairly quickly with a simple workflow. Dig deeper by reading about the [command line interface](https://showyourwork.readthedocs.io/en/latest/cli), the [recommended project layout](https://showyourwork.readthedocs.io/en/latest/layout), the workflow [configuration file](https://showyourwork.readthedocs.io/en/latest/config), and details about the [integration with LaTeX](https://showyourwork.readthedocs.io/en/latest/latex). You can also check out a list of example projects that use `showyourwork!` [here](https://showyourwork.readthedocs.io/en/latest/projects).

`showyourwork!` is a work in progress, so please look over the [issues page](https://github.com/showyourwork/showyourwork/issues) if you think you’ve spotted a bug, and feel free to [raise a new issue](https://github.com/showyourwork/showyourwork/issues/new) if needed! Community contributions are also most welcome.

==> showyourwork-0.3.1.post1.tar.gz: showyourwork-0.3.1.post1/README.md <==
<p align="center">
    <a href="https://github.com/showyourwork/showyourwork">
        <img width = "450" src="https://raw.githubusercontent.com/showyourwork/.github/main/images/showyourwork.png" alt="showyourwork"/>
    </a>
    <br/>
    <a href="https://github.com/showyourwork/showyourwork/actions/workflows/tests.yml">
        <img src="https://github.com/showyourwork/showyourwork/actions/workflows/unit_tests.yml/badge.svg" alt="unit tests"/>
    </a>
    <a href="https://github.com/showyourwork/showyourwork/actions/workflows/local_integration_tests.yml">
        <img src="https://github.com/showyourwork/showyourwork/actions/workflows/local_integration_tests.yml/badge.svg" alt="local integration tests"/>
    </a>
    <a href="https://github.com/showyourwork/showyourwork/actions/workflows/remote_integration_tests.yml">
        <img src="https://github.com/showyourwork/showyourwork/actions/workflows/remote_integration_tests.yml/badge.svg" alt="remote integration tests"/>
    </a>
    <a href="https://showyourwork.readthedocs.io">
        <img src="https://img.shields.io/static/v1?label=read&message=the%20docs&color=blue" alt="tests"/>
    </a>
    <a href="https://github.com/showyourwork/showyourwork-action/network/dependents">
        <img src="https://img.shields.io/static/v1?label=sample&message=projects&color=green" alt="sample projects"/>
    </a>
    <a href="https://pypi.org/project/showyourwork/">
        <img src="https://img.shields.io/pypi/v/showyourwork" alt="pypi"/>
    </a>
</p>

Welcome to `showyourwork!`, a workflow management tool for open source scientific articles. If you want to make your research article **reproducible**, **extensible**, **transparent**, or **just downright awesome**, you’ve found the right tool. `showyourwork!` automates your entire workflow, packaging it into a self-contained recipe that anyone can follow and—at the click of a button—use to reproduce your results.

Please check out the [documentation](https://showyourwork.readthedocs.io) for more information about this project. The [quickstart tutorial](https://showyourwork.readthedocs.io/en/latest/quickstart) should get you up and running fairly quickly with a simple workflow. Dig deeper by reading about the [command line interface](https://showyourwork.readthedocs.io/en/latest/cli), the [recommended project layout](https://showyourwork.readthedocs.io/en/latest/layout), the workflow [configuration file](https://showyourwork.readthedocs.io/en/latest/config), and details about the [integration with LaTeX](https://showyourwork.readthedocs.io/en/latest/latex). You can also check out a list of example projects that use `showyourwork!` [here](https://showyourwork.readthedocs.io/en/latest/projects).

`showyourwork!` is a work in progress, so please look over the [issues page](https://github.com/showyourwork/showyourwork/issues) if you think you’ve spotted a bug, and feel free to [raise a new issue](https://github.com/showyourwork/showyourwork/issues/new) if needed! Community contributions are also most welcome.
